angular.module('tombola-app', ['ngRoute', 'ngAnimate', 'tombola-app.controllers', 'angular.filter'])

.config(function($routeProvider) {
  $routeProvider
    .when('/', {
      controller:'HomeCtrl',
      templateUrl:'partials/home.html'
    })
    .when('/quote', {
      controller:'QuoteCtrl',
      templateUrl:'partials/quote.html'
    })
    .when('/tabellone', {
      controller:'TabelloneCtrl',
      templateUrl:'partials/tabellone.html'
    })
    .when('/about', {
      controller:'AboutCtrl',
      templateUrl:'partials/about.html'
    })
    .otherwise({
      redirectTo:'/'
    });
})

.filter("customCurrency", function (numberFilter)
  {
    function isNumeric(value)
    {
      return (!isNaN(parseFloat(value)) && isFinite(value));
    }

    return function (inputNumber, currencySymbol, decimalSeparator, thousandsSeparator, decimalDigits) {
      if (isNumeric(inputNumber))
      {
        // Default values for the optional arguments
        currencySymbol = (typeof currencySymbol === "undefined") ? "$" : currencySymbol;
        decimalSeparator = (typeof decimalSeparator === "undefined") ? "." : decimalSeparator;
        thousandsSeparator = (typeof thousandsSeparator === "undefined") ? "," : thousandsSeparator;
        decimalDigits = (typeof decimalDigits === "undefined" || !isNumeric(decimalDigits)) ? 2 : decimalDigits;

        if (decimalDigits < 0) decimalDigits = 0;

        // Format the input number through the number filter
        // The resulting number will have "," as a thousands separator
        // and "." as a decimal separator.
        var formattedNumber = numberFilter(inputNumber, decimalDigits);

        // Extract the integral and the decimal parts
        var numberParts = formattedNumber.split(".");

        // Replace the "," symbol in the integral part
        // with the specified thousands separator.
        numberParts[0] = numberParts[0].split(",").join(thousandsSeparator);

        // Compose the final result
        var result = currencySymbol + numberParts[0];

        if (numberParts.length == 2)
        {
          result += decimalSeparator + numberParts[1];
        }

        return result;
      }
      else
      {
        return inputNumber;
      }
    };
  })
  .directive('backButton', function(){
    return {
      restrict: 'A',
 
      link: function(scope, element, attrs) {
        element.bind('click', goBack);
 
        function goBack() {
          history.back();
          scope.$apply();
        }
      }
    };
  })
  .run(function($rootScope, $location, $window) {
    $rootScope.$on( "$routeChangeSuccess", function(event, next, current) {
        
        if ($window.plugins && $window.plugins.gaPlugin) {
        $window.plugins.gaPlugin.trackEvent(function() {console.log("Tracked");}, 
                                            function() {console.log("Not tracked");},
                                            "navigation",
                                            "navigate",
                                            next.$$route.originalPath,
                                            1);
        
        }
    });
  });

